@@ -24,17 +24,18 @@ Lars Wirzenius <liw@iki.fi>
 """
 from __future__ import print_function
 
-import os
-import sys
-import stat
-import time
-import logging
-from signal import alarm, signal, SIGALRM, SIGINT, SIGKILL, SIGHUP, SIGUSR1
-import subprocess
 import fcntl
+import logging
+import os
 import random
+import shlex
+import stat
+import subprocess
+import sys
+import time
+from signal import SIGALRM, SIGHUP, SIGINT, SIGKILL, SIGUSR1, alarm, signal
+
 import apt_pkg
-import pipes
 
 import piupartslib.conf
 import piupartslib.packagesdb
@@ -851,7 +852,7 @@ def log_name(package, version):
 
 def command2string(command):
     """Quote s.t. copy+paste from the logfile gives a runnable command in the shell."""
-    return " ".join([pipes.quote(arg) for arg in command])
+    return " ".join([shlex.quote(arg) for arg in command])
 
 
 def run_test_with_timeout(cmd, maxwait, kill_all=True):
